@@ -1,6 +1,6 @@
 package Term::FormatColumns;
 # ABSTRACT: Format lists of data into columns across the terminal's width
-$Term::FormatColumns::VERSION = '0.006';
+$Term::FormatColumns::VERSION = '0.007';
 use strict;
 use warnings;
 
@@ -86,7 +86,7 @@ Term::FormatColumns - Format lists of data into columns across the terminal's wi
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -129,9 +129,15 @@ being attached to a known/knowable terminal.
 
 Doug Bell <preaction@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Marius Gavrilescu
+
+Marius Gavrilescu <marius@ieval.ro>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Doug Bell.
+This software is copyright (c) 2015 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
